@@ -349,14 +349,20 @@ class Registry(Mapping[URI, Resource[D]]):
 
     def anchor(self, uri: URI, name: str):
         """
-        Retrieve the given anchor, which must already have been found.
+        Retrieve a given anchor from a resource which must already be crawled.
         """
-        value = self._anchors.get((uri, name))
+        resource = self.get(uri)
+        if resource is None:
+            canonical_uri = uri
+        else:
+            canonical_uri = resource.id() or uri
+
+        value = self._anchors.get((canonical_uri, name))
         if value is not None:
             return Retrieved(value=value, registry=self)
 
         registry = self.crawl()
-        value = registry._anchors.get((uri, name))
+        value = registry._anchors.get((canonical_uri, name))
         if value is not None:
             return Retrieved(value=value, registry=registry)
         if "/" in name:
